# frozen_string_literal: true

require 'google_drive'

module PeopleGroup
  module Connectors
    class GoogleSheets
      def spreadsheet(title)
        retry_on_error { session.spreadsheet_by_title(title) }
      end

      def worksheet(spreadsheet_title, worksheet_title)
        worksheets = retry_on_error { spreadsheet(spreadsheet_title).worksheets }
        worksheets.find { |worksheet| worksheet.title == worksheet_title }
      end

      private

      def service_account_key
        StringIO.new(Base64.strict_decode64(ENV['GOOGLE_SERVICE_ACCOUNT_KEY']))
      end

      def session
        @session ||= retry_on_error { GoogleDrive::Session.from_service_account_key(service_account_key) }
      end

      def retry_on_error(&block)
        Utils.retry_on_error(errors: [Google::Apis::ServerError], delay: 3, max_attempts: 4, &block)
      end
    end
  end
end
